# Story Output

**Created:** {{date}}
**Storyteller:** {{agent_role}} {{agent_name}}
**Author:** {{user_name}}

## Story Information

**Story Type:** {{story_type}}

**Framework Used:** {{framework_name}}

**Purpose:** {{story_purpose}}

**Target Audience:** {{target_audience}}

## Story Structure

### Opening Hook

{{opening_hook}}

### Core Narrative

{{core_narrative}}

### Key Story Beats

{{story_beats}}

### Emotional Arc

{{emotional_arc}}

### Resolution/Call to Action

{{resolution}}

## Complete Story

{{complete_story}}

## Story Elements Analysis

### Character/Voice

{{character_voice}}

### Conflict/Tension

{{conflict_tension}}

### Transformation/Change

{{transformation}}

### Emotional Touchpoints

{{emotional_touchpoints}}

### Key Messages

{{key_messages}}

## Variations AND Adaptations

### Short Version (Tweet/Social)

{{short_version}}

### Medium Version (Email/Blog)

{{medium_version}}

### Extended Version (Article/Presentation)

{{extended_version}}

## Usage Guidelines

### Best Channels

{{best_channels}}

### Audience Considerations

{{audience_considerations}}

### Tone AND Voice Notes

{{tone_notes}}

### Adaptation Suggestions

{{adaptation_suggestions}}

## Next Steps

### Refinement Opportunities

{{refinement_opportunities}}

### Additional Versions Needed

{{additional_versions}}

### Testing/Feedback Plan

{{feedback_plan}}

---

_Story crafted using the BMAD CIS storytelling framework_
